@@ -1,7 +1,7 @@
 ## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
-  comment = "#>", out.width = "80%", fig.width = 7, fig.height = 5, 
+  comment = "#>", out.width = "80%", fig.width = 7, fig.height = 5,
   fig.align = "center"
 )
 
@@ -9,21 +9,19 @@ knitr::opts_chunk$set(
 library(epiworldR)
 model_seirconn <- ModelSEIRCONN(
   name              = "COVID-19",
-  n                 = 10000, 
-  prevalence        = 0.0001, 
+  n                 = 10000,
+  prevalence        = 0.0001,
   contact_rate      = 2,
   transmission_rate = 0.5,
   incubation_days   = 7,
-  recovery_rate     = 1/3
-  )
-
+  recovery_rate     = 1 / 3
+)
 
 ## ----saver-generation---------------------------------------------------------
 # Generating a saver
 saver <- make_saver("total_hist", "reproductive")
 # Running and printing
-run_multiple(model_seirconn, ndays = 50, nsims = 50, saver = saver, nthread = 2)
-
+run_multiple(model_seirconn, ndays = 50, nsims = 50, saver = saver, nthreads = 2)
 
 ## ----retrieving results-------------------------------------------------------
 # Retrieving the results
@@ -31,10 +29,9 @@ ans <- run_multiple_get_results(model_seirconn)
 head(ans$total_hist)
 head(ans$reproductive)
 
-
 ## ----plotting seirconn epicurves----------------------------------------------
 seirconn_50 <- run_multiple_get_results(model_seirconn)$total_hist
-seirconn_50 <- seirconn_50[seirconn_50$date <= 20,]
+seirconn_50 <- seirconn_50[seirconn_50$date <= 20, ]
 plot(seirconn_50)
 
 ## ----reproductive number plot-------------------------------------------------
@@ -47,4 +44,3 @@ plot(seirconn_50_r)
 #         border = "black",
 #         las = 2)
 
-
