@@ -639,6 +639,18 @@ inline void DataBase<TSeq>::get_hist_tool(
 
 }
 
+template<typename TSeq>
+inline void DataBase<TSeq>::get_today_transition_matrix(
+    std::vector< int > & counts
+) const
+{
+
+    counts = transition_matrix;
+
+    return;
+
+}
+
 template<typename TSeq>
 inline void DataBase<TSeq>::get_hist_transition_matrix(
     std::vector< std::string > & state_from,
@@ -821,9 +833,9 @@ inline void DataBase<TSeq>::write_data(
 
         file_virus <<
             #ifdef EPI_DEBUG
-            "thread "<< "date " << "id " << "state " << "n\n";
+            "thread "<< "date " << "virus_id " << "virus " << "state " << "n\n";
             #else
-            "date " << "virus_id virus" << "state " << "n\n";
+            "date " << "virus_id " << "virus " << "state " << "n\n";
             #endif
 
         for (epiworld_fast_uint i = 0; i < hist_virus_id.size(); ++i)
@@ -995,9 +1007,9 @@ inline void DataBase<TSeq>::write_data(
                         #ifdef EPI_DEBUG
                         EPI_GET_THREAD_ID() << " " <<
                         #endif
-                        i << " " <<
-                        model->states_labels[from] << " " <<
-                        model->states_labels[to] << " " <<
+                        i << " \"" <<
+                        model->states_labels[from] << "\" \"" <<
+                        model->states_labels[to] << "\" " <<
                         hist_transition_matrix[i * (ns * ns) + to * ns + from] << "\n";
                 
         }
